@@ -1,5 +1,6 @@
 import io
 import os
+from functools import partial
 from io import BytesIO
 
 from PIL import Image as pilim
@@ -46,7 +47,8 @@ __location__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(__file
 
 class ReportLabPDFBuilder:
 
-    def __init__(self, logo_path=None, watermark=None, pdf_tab_title=PDF_TAB_TITLE, logo_base_width=LOGO_BASE_WIDTH):
+    def __init__(self, logo_path=None, watermark=None, pdf_tab_title=PDF_TAB_TITLE, logo_base_width=LOGO_BASE_WIDTH,
+                 logo_canvas_x=0, logo_canvas_y=0):
         global WATERMARK
         global LOGO_PATH
         global BODY_STYLE
@@ -71,7 +73,8 @@ class ReportLabPDFBuilder:
             rightPadding=FRAME_RIGHT_PADDING,
             topPadding=FRAME_TOP_PADDING
         )
-        template = PageTemplate(id='all_pages', frames=frame, onPage=header_and_footer)
+        header_and_footer_partial = partial(header_and_footer, logo_canvas_x, logo_canvas_y)
+        template = PageTemplate(id='all_pages', frames=frame, onPage=header_and_footer_partial)
         self.pdf.addPageTemplates([template])
         self.story = []
 
@@ -258,7 +261,7 @@ def pfd_table_builder(data, fonts=None):
     return t
 
 
-def header_and_footer(canvas, pdf):
+def header_and_footer(logo_canvas_x, logo_canvas_y, canvas, pdf):
     canvas.setTitle(PDF_TAB_TITLE)
 
     # LOGO
@@ -269,11 +272,13 @@ def header_and_footer(canvas, pdf):
             img_height=im.size[1],
             img_desired_width=LOGO_BASE_WIDTH
         )
+        print(print_width)
+        print(print_height)
         pil_img = ImageReader(im)
         canvas.drawImage(
             pil_img,
-            PAGE_WIDTH / 2 - 60,
-            PAGE_HEIGHT - print_height + 40,
+            logo_canvas_x,
+            logo_canvas_y,
             width=print_width,
             height=print_height,
             mask='auto'
